using Tiger.Communication.Messages.Interfaces;
using Tiger.Communication.Messages.Outgoing.Catalog;
using Tiger.Communication.Messages.Types;
using Tiger.Game.Catalogue;
using Tiger.Networking.Game.Sessions;

namespace Tiger.Communication.Messages.Incoming.Catalog;

public class GetCatalogIndexEvent : IMessageEvent
{
    private readonly ICatalogueManager _catalogueManager;
    private readonly IGameSessionManager _gameSessionManager;

    public GetCatalogIndexEvent(ICatalogueManager catalogueManager, IGameSessionManager gameSessionManager)
    {
        _catalogueManager = catalogueManager;
        _gameSessionManager = gameSessionManager;
    }

    public IncomingHeaders Header => IncomingHeaders.GetCatalogIndexEvent;
    public async Task HandleAsync(GameSession gameSession, ClientMessage request)
    {
        if (gameSession.Habbo == null)
        {
            await _gameSessionManager.CloseAsync("Not logged in", gameSession);
            return;
        }
        
        var categories = _catalogueManager.Pages.Values.Where(p => p.Parent is null);

        await gameSession.SendComposerAsync(new CatalogIndexMessageComposer(categories,
            request.ReadString() ?? "normal"));
    }
}